# Copyright (c) Lawrence Livermore National Security, LLC and other VisIt
# Project developers.  See the top-level LICENSE file for dates and other
# details.  No copyright assignment is required to contribute to VisIt.

#*****************************************************************************
# Modifications:
#   David M. Camp, Th Jan 14 11:50:00 PST 2010
#   Added new function ADD_TARGET_DEFINITIONS to add defines to targets.
#   This was needed for the plots to define ENGINE only for the engine build.
#
#   Brad Whitlock, Thu May 27 09:30:00 PDT 2010
#   Wrap setting the compiler in an if-exists test.
#
#   Mark C. Miller, Thu Jul 29 17:37:32 PDT 2010
#   Added block for compiler version comments.
#
#   Brad Whitlock, Tue Aug 17 09:17:19 PDT 2010
#   I added NETCDF_CXX_LIB.
#
#   Brad Whitlock, Wed Oct 27 14:12:19 PDT 2010
#   Make sure that TESSELLATION_LIBRARY gets saved.
#
#   Kathleen Bonnell, Thu Dec 2 15:45:44 MST 2010
#   Allow plugin installs on Windows. 
#   Added BOOST_INCLUDE_DIR, TESSELLATION_LIBRARY. 
#   Expand SLIVR_INCLUDE_DIR.  
#   Add defintions for HAVE_LIBGLEW, HAVE_LIBSLIVR (if VISIT_SLIVR).  
#   Only set TUVOK_LIB if VISIT_TUVOK is ON.  
#   Add preprocessor definitions for Windows.
#   Add VISIT_PYTHON_SCRIPTING.
#
#   Brad Whitlock, Thu Jun 23 17:03:35 PDT 2011
#   Fix python library extension for Mac.
#
#   Kathleen Biagas, Thu Jun 21 11:12:57 MST 2012
#   Include paths for vtk, exodusii, python and lib names for ptyhon are 
#   different on windows than unix, so use special vars set in root 
#   CMakeLists.txt file.  Fix boxlib include and lib var names.
#   Added fix for automatic debug flags setting on windows, to allow proper
#   linking with our default release-version third-party libraries.
#   Added 'ADD_TARGET_INCLUDE' function, change how parallel flags are 
#   handled on windows. Fix glitch with ADD_TARGET_DEFINITIONS when target
#   had more than one definition set already.
#
#   Kathleen Biagas, Tue Oct 29 12:24:32 MST 2013
#   Fixed typos in Functions that prevented caused problems on Windows.
#
#   Kathleen Biagas, Fri Oct 31 11:22:25 PDT 2014
#   Compare visual studio versions on windows (if using MSVC) instead of
#   comparing compiler paths.  Enclose /usr/bin/gcc in quotes to 
#   handle spaces-in-paths on windows that causes warnings for this script.
#   Remove setting of Windows Definitions, VISIT_PLUGIN_TARGET_RTOD,
#   ADD_TARGET_INCLUDE, ADD_TARGET_DEFINITIONS, ADD_PARALLEL_LIBRARY, as
#   these are now available in VisItMacros.cmake, and can be used without
#   re-write.  Include VisItMacros.cmake.
#
#   Cyrus Harrison, Tue Feb 10 20:06:07 PST 2015
#   Changed boost support.
#
#   Iulian R. Grindeanu & Vijay S. Mahadevan via Mark C Miller
#   Wed Aug 10 14:54:05 PDT 2016
#   Added support for ANL's Mesh Object datABase (MOAB)
#
#   Kathleen Biagas, Fri Mar  2 14:51:27 MST 2018
#   Removed TUVOK.
#
#   Kathleen Biagas, Thu Sep 27 11:29:37 PDT 2018
#   Added mfem. Fix cmake logic for MSVC. Fix boost, Qt.  Add
#   get_filename_component calls to get root install directory for setting
#   VISIT_INCLUDE_DIR, VISIT_LIBRARY_DIR, VISIT_BINARY_DIR, VISIT_ARCHIVE_DIR.
#
#   Kathleen Biagas, Thu Nov  8 10:10:06 PST 2018
#   Added VTKh_INCLUDE_DIRS and VTKM_DIR.
#
#   Kathleen Biagas, Wed Apr 17 12:54:40 PDT 2019
#   MFEM has an include dependency on conduit, move it below conduit in the
#   list and add conduit include to it's include.
#
#   Eric Brugger, Wed Jun 26 10:01:32 PDT 2019
#   Removed the CCM reader.
#
#   Kathleen Biagas, Fri Jul 19 12:11:05 PDT 2019
#   Added ZLIB. Removed SLIVR. Added zlib to MFEM include.
#
#   Kevin Griffin, Thu Aug 8 18:30:27 PDT 2019
#   Added the correct paths for the QT_QT*_INCLUDE_DIR variables for OSX.
#
#   Eddie Rusu, Wed Oct 14 15:52:13 PDT 2020
#   Removed FastBit and FastQuery
#
#****************************************************************************/

##
## This file gets generated by VisIt's top-level CMakeLists.txt and gets 
## installed along with VisIt so 3rd party plugins can be developed against an 
## installed version of VisIt.
##

# Build shared libraries since we're building plugins.
set(BUILD_SHARED_LIBS 1)


# Warn if compilers might be incompatible.
if(WIN32 AND MSVC)
    if(NOT  STREQUAL ${MSVC_VERSION})
      message(WARNING "MSVC version used for VisIt () differs from the one used for the current project ${MSVC_VERSION}!  They may incompatible.")
    endif()
else()
    if(EXISTS "/usr/bin/gcc" AND
       NOT ${CMAKE_C_COMPILER} STREQUAL "/usr/bin/gcc")
      message(WARNING "C compiler used for VisIt (/usr/bin/gcc)\n"
              "differs from the one used for the current project!\n"
              "(${CMAKE_C_COMPILER}) They may be incompatible.")
    endif()
    if(EXISTS "/usr/bin/g++" AND
       NOT ${CMAKE_CXX_COMPILER} STREQUAL "/usr/bin/g++")
      message(WARNING "C++ compiler used for VisIt (/usr/bin/g++)\n"
              "differs from the one used for the current project!\n"
              "(${CMAKE_CXX_COMPILER})  They may be incompatible.")
    endif()
endif()


# The comment below is intended to capture version information
# of the compiler in use at the time CMake was invoked to build
# VisIt. If there is no comment in the intervening lines, then
# compiler version information was not successfully obtained.
# -------------------------------------------------------------
# gcc (GCC) 8.3.1 20191121 (Red Hat 8.3.1-5)
# Copyright (C) 2018 Free Software Foundation, Inc.
# This is free software; see the source for copying conditions.  There is NO
# warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# 
# g++ (GCC) 8.3.1 20191121 (Red Hat 8.3.1-5)
# Copyright (C) 2018 Free Software Foundation, Inc.
# This is free software; see the source for copying conditions.  There is NO
# warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# 
# -------------------------------------------------------------

# this should return the installed/include path
get_filename_component(_IMPORT_PREFIX "${CMAKE_CURRENT_LIST_FILE}" PATH)
# this should strip off the include
get_filename_component(_IMPORT_PREFIX "${_IMPORT_PREFIX}" PATH)

set(VISIT_INCLUDE_DIR "${_IMPORT_PREFIX}/include")
set(VISIT_LIBRARY_DIR "${_IMPORT_PREFIX}/lib")
if(WIN32)
  set(VISIT_BINARY_DIR  "${_IMPORT_PREFIX}")
  set(VISIT_ARCHIVE_DIR "${_IMPORT_PREFIX}/lib")
else()
  set(VISIT_BINARY_DIR  "${_IMPORT_PREFIX}/bin")
  set(VISIT_ARCHIVE_DIR "${_IMPORT_PREFIX}/archives")
endif()

include(${VISIT_INCLUDE_DIR}/CheckMinimumCompilerVersion.cmake)

# Commonly used VisIt include directories
set(VISIT_COMMON_INCLUDES
    ${VISIT_INCLUDE_DIR}/visit/include
    ${VISIT_INCLUDE_DIR}/visit/common/Exceptions/Database
    ${VISIT_INCLUDE_DIR}/visit/common/Exceptions/Pipeline
    ${VISIT_INCLUDE_DIR}/visit/common/Exceptions/Plotter
    ${VISIT_INCLUDE_DIR}/visit/common/comm
    ${VISIT_INCLUDE_DIR}/visit/common/expr
    ${VISIT_INCLUDE_DIR}/visit/common/icons
    ${VISIT_INCLUDE_DIR}/visit/common/misc
    ${VISIT_INCLUDE_DIR}/visit/common/parser
    ${VISIT_INCLUDE_DIR}/visit/common/plugin
    ${VISIT_INCLUDE_DIR}/visit/common/proxybase
    ${VISIT_INCLUDE_DIR}/visit/common/state
    ${VISIT_INCLUDE_DIR}/visit/common/utility
)

set(HAVE_LIBZ true)
if(HAVE_LIBZ)
    set(ZLIB_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/zlib/include)
    list(APPEND VISIT_COMMON_INCLUDES ${ZLIB_INCLUDE_DIR})
endif()

# VisIt options
set(VISIT_PYTHON_SCRIPTING       ON)
set(VISIT_SERVER_COMPONENTS_ONLY OFF)
set(VISIT_ENGINE_ONLY            OFF)
set(VISIT_DBIO_ONLY              OFF)
set(VISIT_PARALLEL               ON)
set(VISIT_JAVA                   ON)
set(VISIT_SLIVR                  ON)
set(VISIT_OSPRAY                 OFF)

# Set up VTK
set(VTK_INCLUDE_DIRS ${VISIT_INCLUDE_DIR}/vtk/vtk-8.1)
set(VTK_LIBRARY_DIRS ${VISIT_LIBRARY_DIR})

# Set up OpenGL
set(OPENGL_INCLUDE_DIR  /usr/include)
set(OPENGL_gl_LIBRARY   /usr/lib64/libGL.so)
set(OPENGL_glu_LIBRARY  /usr/lib64/libGLU.so)
set(OPENGL_LIBRARIES    /usr/lib64/libGL.so;/usr/lib64/libGLU.so)

# Set up the tessellation library
set(TESSELLATION_LIBRARY /usr/lib64/libGLU.so;/usr/lib64/libGL.so)

# Set up BOOST
set(BOOST_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/boost/include/boost)

# Set up Qt
if(APPLE)
    set(QT_INCLUDE_DIR           ${VISIT_INCLUDE_DIR}/qt/include)
    set(QT_QTCORE_INCLUDE_DIR    ${VISIT_LIBRARY_DIR}/QtCore.framework/Versions/Current/Headers)
    set(QT_QTGUI_INCLUDE_DIR     ${VISIT_LIBRARY_DIR}/QtGui.framework/Versions/Current/Headers)
    set(QT_QTOPENGL_INCLUDE_DIR  ${VISIT_LIBRARY_DIR}/QtOpenGL.framework/Versions/Current/Headers)
    set(QT_QTWIDGETS_INCLUDE_DIR ${VISIT_LIBRARY_DIR}/QtWidgets.framework/Versions/Current/Headers)
    set(QT_QTXML_INCLUDE_DIR     ${VISIT_LIBRARY_DIR}/QtXml.framework/Versions/Current/Headers)
else()
    set(QT_INCLUDE_DIR           ${VISIT_INCLUDE_DIR}/qt/include)
    set(QT_QTCORE_INCLUDE_DIR    ${VISIT_INCLUDE_DIR}/qt/include/QtCore)
    set(QT_QTGUI_INCLUDE_DIR     ${VISIT_INCLUDE_DIR}/qt/include/QtGui)
    set(QT_QTOPENGL_INCLUDE_DIR  ${VISIT_INCLUDE_DIR}/qt/include/QtOpenGL)
    set(QT_QTWIDGETS_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/qt/include/QtWidgets)
    set(QT_QTXML_INCLUDE_DIR     ${VISIT_INCLUDE_DIR}/qt/include/QtXml)
endif()

set(QT_LIBRARY_DIR           ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(QT_BIN                   ${VISIT_BINARY_DIR})
set(QT_MOC_EXECUTABLE        ${VISIT_BINARY_DIR}/moc)

# Set up Python
set(PYTHON_INCLUDE_PATH    ${VISIT_INCLUDE_DIR}/python/include/python2.7)
set(PYTHON_LIBRARY         ${VISIT_LIBRARY_DIR}/libpython2.7.so)

if(VISIT_OSPRAY)
    set(OSPRAY_INCLUDE_DIR    ${VISIT_INCLUDE_DIR})
    set(OSPRAY_LIBRARIES      )
endif()

# Set up 3rd party I/O libraries
set(ADIOS_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/adios/include)
set(ADIOS_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(ADIOS_LIB libadiosread.a;libadiosread_nompi.a)

set(ADVIO_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/advio/include)
set(ADVIO_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(ADVIO_LIB libAdvDocIO.a;libAdvFileIO.a;libAdvBase.a)

set(BOXLIB_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/boxlib/include)
set(BOXLIB_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(BOXLIB_2D_LIB libbox2D.a)
set(BOXLIB_3D_LIB libbox3D.a)

set(CFITSIO_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/cfitsio/include)
set(CFITSIO_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(CFITSIO_LIB libcfitsio.a)

set(CGNS_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/cgns/include)
set(CGNS_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(CGNS_LIB libcgns.so;libhdf5.so;libsz.so;libz.so)

set(EXODUSII_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/)
set(EXODUSII_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(EXODUSII_LIB )

set(GDAL_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/gdal/include)
set(GDAL_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(GDAL_LIB libgdal.a)

set(HDF4_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/hdf4/include)
set(HDF4_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(HDF4_LIB libmfhdf.a;libdf.a;libsz.so;libvtkjpeg-8.1.so)

set(HDF5_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/hdf5/include)
set(HDF5_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(HDF5_LIB libhdf5.so;libsz.so;libz.so)
if(VISIT_PARALLEL)
    set(HDF5_MPI_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/hdf5_mpi/include)
    set(HDF5_MPI_LIBRARY_DIR ${VISIT_LIBRARY_DIR}/hdf5_mpi ${VISIT_ARCHIVE_DIR})
    set(HDF5_MPI_LIB )
endif()

set(H5PART_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/h5part/include)
set(H5PART_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(H5PART_LIB libH5Part.a;libhdf5.so;libsz.so;libz.so)

set(MOAB_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/moab/include)
set(MOAB_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(MOAB_LIB )
if(VISIT_PARALLEL)
    set(MOAB_MPI_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/moab_mpi/include)
    set(MOAB_MPI_LIBRARY_DIR ${VISIT_LIBRARY_DIR}/moab_mpi ${VISIT_ARCHIVE_DIR})
    set(MOAB_MPI_LIB )
endif()

set(MILI_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/mili/include)
set(MILI_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(MILI_LIB libmili.a)

set(NETCDF_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/netcdf/include)
set(NETCDF_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(NETCDF_LIB libnetcdf.a;libhdf5_hl.so;libhdf5.so;libsz.so;libz.so)
set(NETCDF_CXX_LIB libnetcdf_c++.a)

set(PDB_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/silo/include)
set(PDB_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(PDB_LIB libsiloh5.so;libhdf5.so;libsz.so;libz.so;libz.so)

set(SILO_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/silo/include)
set(SILO_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(SILO_LIB libsiloh5.so;libhdf5.so;libsz.so;libz.so;libz.so)

set(XDMF_INCLUDE_DIR  ${VISIT_INCLUDE_DIR}/xdmf/include)
set(XDMF_LIBRARY_DIR  ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(XDMF_LIB libXdmf.so;libhdf5.so;libvtklibxml2-8.1.so)


set(CONDUIT_INCLUDE_DIR  ${VISIT_INCLUDE_DIR}/conduit/conduit)
set(CONDUIT_LIBRARY_DIR  ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(CONDUIT_LIB libconduit.so;libconduit_relay.so;libconduit_blueprint.so;libhdf5.so;libsz.so;libz.so)
if(VISIT_PARALLEL)
    set(CONDUIT_MPI_INCLUDE_DIR ${VISIT_INCLUDE_DIR}/conduit/conduit)
    set(CONDUIT_MPI_LIBRARY_DIR ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
    set(CONDUIT_MPI_LIB libconduit_relay_mpi.so)
endif()

# mfem include, fudge because we know that the includes should be
set(MFEM_INCLUDE_DIR  ${VISIT_INCLUDE_DIR}/mfem/include;${CONDUIT_INCLUDE_DIR};${ZLIB_INCLUDE_DIR})
set(MFEM_LIBRARY_DIR  ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(MFEM_LIB libmfem.a)

set(OPENEXR_INCLUDE_DIR  ${VISIT_INCLUDE_DIR}/openexr/OpenEXR)
set(OPENEXR_LIBRARY_DIR  ${VISIT_LIBRARY_DIR} ${VISIT_ARCHIVE_DIR})
set(OPENEXR_LIB )

set(VTKh_INCLUDE_DIRS  ${VISIT_INCLUDE_DIR}/vtkh/include)
set(VTKM_DIR           ${VISIT_INCLUDE_DIR}/vtkm)

include(${VISIT_INCLUDE_DIR}/VisItMacros.cmake)

# Installation macros
macro(VISIT_INSTALL_DATABASE_PLUGINS)
    foreach(target ${ARGN})
        set_target_properties(${target} PROPERTIES
           RUNTIME_OUTPUT_DIRECTORY "${VISIT_PLUGIN_DIR}/databases"
           LIBRARY_OUTPUT_DIRECTORY "${VISIT_PLUGIN_DIR}/databases"
        )
    endforeach()
endmacro()

macro(VISIT_INSTALL_OPERATOR_PLUGINS)
    foreach(target ${ARGN})
        set_target_properties(${target} PROPERTIES
           RUNTIME_OUTPUT_DIRECTORY "${VISIT_PLUGIN_DIR}/operators"
           LIBRARY_OUTPUT_DIRECTORY "${VISIT_PLUGIN_DIR}/operators"
        )
    endforeach()
endmacro()

macro(VISIT_INSTALL_PLOT_PLUGINS)
    foreach(target ${ARGN})
        set_target_properties(${target} PROPERTIES
           RUNTIME_OUTPUT_DIRECTORY "${VISIT_PLUGIN_DIR}/plots"
           LIBRARY_OUTPUT_DIRECTORY "${VISIT_PLUGIN_DIR}/plots"
        )
    endforeach()
endmacro()

macro(VISIT_PLUGIN_TARGET_FOLDER type pname)
    message(STATUS "Skipping VISIT_PLUGIN_TARGET_FOLDER macro")
endmacro()

# Parallel settings
set(VISIT_PARALLEL_CXXFLAGS     -DPARALLEL -DMPICH_IGNORE_CXX_SEEK -DMPICH_SKIP_MPICXX -DOMPI_SKIP_MPICXX -DMPI_NO_CPPBIND -DPARALLEL -DMPICH_IGNORE_CXX_SEEK  -I/usr/local/openmpi/4.1.0/gcc/include )
set(VISIT_PARALLEL_LINKER_FLAGS -Wl,-rpath -Wl,/usr/lib64 -Wl,-rpath -Wl,/usr/local/openmpi/4.1.0/gcc/lib64 -Wl,--enable-new-dtags)
set(VISIT_PARALLEL_LIBS         "/usr/local/openmpi/4.1.0/gcc/lib64/libmpi.so")
set(VISIT_PARALLEL_INCLUDE      "")
set(VISIT_PARALLEL_DEFS         )
set(VISIT_NOLINK_MPI_WITH_LIBRARIES OFF)

